@@ -1,8 +1,7 @@
 import socketio
-from typing import Union
+from typing import Optional, Union
 from fastapi import FastAPI
 
-
 class SocketManager:
     """
     Integrates SocketIO with FastAPI app. 
@@ -23,9 +22,10 @@ class SocketManager:
         mount_location: str = "/ws",
         socketio_path: str = "socket.io",
         cors_allowed_origins: Union[str, list] = '*',
+        async_mode: str = "asgi"
     ) -> None:
         # TODO: Change Cors policy based on fastapi cors Middleware
-        self._sio = socketio.AsyncServer(async_mode="asgi", cors_allowed_origins=cors_allowed_origins)
+        self._sio = socketio.AsyncServer(async_mode=async_mode, cors_allowed_origins=cors_allowed_origins)
         self._app = socketio.ASGIApp(
             socketio_server=self._sio, socketio_path=socketio_path
         )
@@ -87,3 +87,12 @@ class SocketManager:
     @property
     def sleep(self):
         return self._sio.sleep
+
+    @property
+    def enter_room(self, sid: str, room: str, namespace: Optional[str] = None):
+        return self._sio.enter_room(sid, room, namespace)
+
+    @property
+    def leave_room(self, sid: str, room: str, namespace: Optional[str] = None):
+        return self._sio.leave_room(sid, room, namespace)
+
